#!/usr/bin/env python3
"""
This file parses the JSON output of Rocprof to get aggregated statistics for
GPU performance analysis.
Don't forget to load the cray-python module before running the script!
"""

import json
import numpy as np


def _load_json(iteration, nlat, nlon):
    """Load JSON output and slice into the requested iteration."""
    start_kernel = "( kernel(eltinv$eltinv_mod_$ck_L136_2_cce$noloop$form)"
    
    # Read JSON file.
    with open(f"../profiling/workload_tests/res-gpu_prof_nlat_{nlat}_" + 
              f"nlon_{nlon}/rocprof.json") as fp:
        data = json.load(fp)
        data = np.array(data["traceEvents"])
                
    # Variables for tracking the iteration, and storing start and end indexes 
    # of the requested itteration.
    cur_itter = 0
    start_index = -1
    end_index = -1
    
    # Loop over the JSON data until requested itteration is found.
    for i, dict_item in enumerate(iter(data)):
        if not dict_item.keys() \
           or "args" not in dict_item \
           or "args" not in dict_item["args"]:
            continue
        
        if dict_item["name"].startswith("hipModuleLaunchKernel") \
           and dict_item["args"]["args"].startswith(start_kernel):
            cur_itter += 1
            
            if cur_itter == iteration:
                start_index = i
                print("Found 7th at idx: ", start_index)
            elif cur_itter == iteration + 1:
                end_index = i
                print("Found 8th at idx: ", end_index)
                break

    # Return slice of the JSON file which only contains requested itteration.
    return data[start_index:end_index]


if __name__ == "__main__":
    # Load the JSON file.
    iteration = 7    
    nlat_nlon = (128,128)
    _load_json(iteration, *nlat_nlon)
    
    pass
